@@ -49,7 +49,7 @@ const struct value_string osmo_bts_variant_names[_NUM_BTS_VARIANT + 1] = {
 	{ BTS_OSMO_LITECELL15,	"osmo-bts-lc15" },
 	{ BTS_OSMO_OCTPHY,	"osmo-bts-octphy" },
 	{ BTS_OSMO_SYSMO,	"osmo-bts-sysmo" },
-	{ BTS_OSMO_TRX,		"omso-bts-trx" },
+	{ BTS_OSMO_TRX,		"osmo-bts-trx" },
 	{ 0, NULL }
 };
 
@@ -470,6 +470,7 @@ struct gsm_bts *gsm_bts_alloc(struct gsm_network *net, struct gsm_bts_sm *bts_sm
 	bts->interf_meas_params_cfg = interf_meas_params_def;
 
 	bts->rach_max_delay = 63;
+	bts->rach_expiry_timeout = 32;
 
 	/* SRVCC is enabled by default */
 	bts->srvcc_fast_return_allowed = true;
@@ -765,7 +766,8 @@ struct gsm_bts_trx *gsm_bts_trx_num(const struct gsm_bts *bts, int num)
 
 void bts_store_uptime(struct gsm_bts *bts)
 {
-	osmo_stat_item_set(osmo_stat_item_group_get_item(bts->bts_statg, BTS_STAT_UPTIME_SECONDS), bts_uptime(bts));
+	osmo_stat_item_set(osmo_stat_item_group_get_item(bts->bts_statg, BTS_STAT_UPTIME_SECONDS),
+			   bts->oml_link ? bts_updowntime(bts) : 0);
 }
 
 void bts_store_lchan_durations(struct gsm_bts *bts)
@@ -823,20 +825,20 @@ void bts_store_lchan_durations(struct gsm_bts *bts)
 	rate_ctr_add(rate_ctr_group_get_ctr(bts->bts_ctrs, BTS_CTR_CHAN_SDCCH_ACTIVE_MILLISECONDS_TOTAL), elapsed_sdcch_ms);
 }
 
-unsigned long long bts_uptime(const struct gsm_bts *bts)
+unsigned long long bts_updowntime(const struct gsm_bts *bts)
 {
 	struct timespec tp;
 
-	if (!bts->uptime || !bts->oml_link)
+	if (!bts->updowntime)
 		return 0;
 
 	if (osmo_clock_gettime(CLOCK_MONOTONIC, &tp) != 0) {
-		LOGP(DNM, LOGL_ERROR, "BTS %u uptime computation failure: %s\n", bts->nr, strerror(errno));
+		LOGP(DNM, LOGL_ERROR, "BTS %u uptime/downtime computation failure: %s\n", bts->nr, strerror(errno));
 		return 0;
 	}
 
 	/* monotonic clock helps to ensure that the conversion is valid */
-	return difftime(tp.tv_sec, bts->uptime);
+	return difftime(tp.tv_sec, bts->updowntime);
 }
 
 char *get_model_oml_status(const struct gsm_bts *bts)
